BitwuzlaOption
==============

The kind of a Bitwuzla configuration option.

Options are configured via a :cpp:type:`BitwuzlaOptions` instance,
which must be configured before creating a :cpp:type:`Bitwuzla` instance.

.. note::

  Some options are labeled as "expert" options. Use with caution.

----

- enum :cpp:enum:`BitwuzlaOption`

----

.. doxygenenum:: BitwuzlaOption
    :project: Bitwuzla_c
